@@ -24,42 +24,34 @@
 
 #include "kwebkitpart_debug.h"
 #include "kwebkitpart.h"
-#include "websslinfo.h"
 #include "webview.h"
-#include "sslinfodialog_p.h"
 #include "networkaccessmanager.h"
 #include "settings/webkitsettings.h"
 #include "webpluginfactory.h"
 
 #include <KIconLoader>
 #include <KMessageBox>
-#include <KLocale>
 #include <KRun>
 #include <KShell>
-
-#include <KAuthorized>
-#include <KFileDialog>
 #include <KProtocolInfo>
 #include <KStringHandler>
-#include <KMimeType>
 #include <KUrlAuthorized>
-#include <KIO/Job>
-#include <KIO/AccessManager>
-#include <KIO/Scheduler>
-#include <KParts/HtmlExtension>
 #include <KSharedConfig>
+#include <KConfigGroup>
+#include <KLocalizedString>
+
+#include <KIO/Job>
+#include <KParts/HtmlExtension>
 
-#include <QFile>
 #include <QApplication>
-#include <QTextDocument> // Qt::escape
 #include <QNetworkReply>
-#include <QWebFrame>
-#include <QWebElement>
-#include <QWebHistory>
-#include <QWebHistoryItem>
 #include <QWebSecurityOrigin>
 #include <QDesktopWidget>
-#include <QStandardPaths>
+#include <QMimeType>
+#include <QMimeDatabase>
+#include <QLocale>
+#include <QFileDialog>
+#include <QUrlQuery>
 
 #define QL1S(x)  QLatin1String(x)
 #define QL1C(x)  QLatin1Char(x)
@@ -182,11 +174,13 @@ static QString warningIconData()
     QFile f (KIconLoader::global()->iconPath("dialog-warning", -KIconLoader::SizeHuge));
 
     if (f.open(QIODevice::ReadOnly)) {
-        KMimeType::Ptr mime = KMimeType::mimeType(f.fileName(), KMimeType::ResolveAliases);
+        QByteArray fileData = f.readAll();
+        QMimeDatabase db;
+        QMimeType mime = db.mimeTypeForFileNameAndData(f.fileName(), fileData);
         data += QL1S("data:");
-        data += mime ? mime->name() : KMimeType::defaultMimeType();
+        data += mime.name();
         data += QL1S(";base64,");
-        data += f.readAll().toBase64();
+        data += fileData.toBase64();
         f.close();
     }
 
@@ -242,7 +236,7 @@ QString WebPage::errorPage(int code, const QString& text, const QUrl& reqUrl) co
     }
 
     doc += i18n( "Date and Time: %1",
-                 KLocale::global()->formatDateTime(QDateTime::currentDateTime(), KLocale::LongDate) );
+                 QLocale().toString(QDateTime::currentDateTime(), QLocale::LongFormat) );
     doc += QL1S( "</li><li>" );
     // escape text twice: once for i18n, and once for HTML.
     doc += i18n( "Additional Information: %1", text.toHtmlEscaped().toHtmlEscaped() );
@@ -293,11 +287,14 @@ bool WebPage::extension(Extension extension, const ExtensionOption *option, Exte
         QWebPage::ChooseMultipleFilesExtensionReturn *extOutput = static_cast<QWebPage::ChooseMultipleFilesExtensionReturn*>(output);
         if (extOutput && extOption && currentFrame() == extOption->parentFrame) {
             if (extOption->suggestedFileNames.isEmpty())
-                extOutput->fileNames = KFileDialog::getOpenFileNames(QUrl(), QString(), view(),
-                                                                     i18n("Choose files to upload"));
+                extOutput->fileNames = QFileDialog::getOpenFileNames(view(),
+                                                                     i18n("Choose files to upload"),
+                                                                     QString(), QString());
             else
-                extOutput->fileNames = KFileDialog::getOpenFileNames(QUrl(extOption->suggestedFileNames.first()),
-                                                                     QString(), view(), i18n("Choose files to upload"));
+                extOutput->fileNames = QFileDialog::getOpenFileNames(view(),
+                                                                     i18n("Choose files to upload"),
+                                                                     extOption->suggestedFileNames.first(),
+                                                                     QString());
             return true;
         }
         break;
@@ -795,8 +792,8 @@ static QUrl sanitizeMailToUrl(const QUrl &url, QStringList& files) {
     else
       sanitizedUrl = QUrl(url.scheme() + QL1S(":?") + url.path());
 
-    QListIterator<QPair<QString, QString> > it (sanitizedUrl.queryItems());
-    sanitizedUrl.setEncodedQuery(QByteArray());    // clear out the query componenet
+    QListIterator<QPair<QString, QString> > it (QUrlQuery(sanitizedUrl).queryItems());
+    QUrlQuery newQuery;
 
     while (it.hasNext()) {
         QPair<QString, QString> queryItem = it.next();
@@ -808,9 +805,10 @@ static QUrl sanitizeMailToUrl(const QUrl &url, QStringList& files) {
             files << queryItem.second;
             continue;
         }
-        sanitizedUrl.addQueryItem(queryItem.first, queryItem.second);
+        newQuery.addQueryItem(queryItem.first, queryItem.second);
     }
 
+    sanitizedUrl.setQuery(newQuery);			// replace the query component
     return sanitizedUrl;
 }
 
@@ -830,10 +828,12 @@ bool WebPage::handleMailToUrl (const QUrl &url, NavigationType type) const
                                                                                KGuiItem(i18n("&Ignore attachments")), QL1S("WarnEmailAttachment")) == KMessageBox::Continue) {
 
                    // Re-add the attachments...
+                    QUrlQuery newQuery(mailtoUrl);
                     QStringListIterator filesIt (files);
                     while (filesIt.hasNext()) {
-                        mailtoUrl.addQueryItem(QL1S("attach"), filesIt.next());
+                        newQuery.addQueryItem(QL1S("attach"), filesIt.next());
                     }
+                    mailtoUrl.setQuery(newQuery);
                 }
                 break;
             case QWebPage::NavigationTypeFormSubmitted:
